@@ -1,7 +1,7 @@
 import random
 import os
 def rand(rnd1,rnd2):
-  random.randint(rnd1, rnd2)
+  return random.randint(rnd1, rnd2)
 
 def curdir():
   return os.getcwd()
@@ -55,6 +55,7 @@ def rmlist(liste):
     liste = liste.replace(']','')
     liste = liste.replace(',','')
     liste = liste.replace("'", '')
+    return liste
   else:
     print("REQUIRED LIST, GOT: ", type(liste))
     pass
